require 'spec_helper'

describe AltaBikes::City do

  let(:chicago) {AltaBikes::City.new(AltaBikes::Configuration.new)}

  describe '#stations' do
    it 'returns an array of stations' do
      VCR.use_cassette('get_stations_success') do
        stations = chicago.stations
        expect(stations.class).to    eql(Array)
        expect(stations.count).to    be > 0
        expect(stations[0].class).to eql(AltaBikes::Station)
      end
    end

    it 'returns a single station' do
      VCR.use_cassette('get_stations_success') do
        station = chicago.stations(32)
        expect(station.class).to eql(AltaBikes::Station)
      end
    end

    it 'returns nil for an unknown ID' do
      VCR.use_cassette('get_stations_success') do
        station = chicago.stations(999)
        expect(station).to be_nil
      end
    end

    it 'returns a StationListUnavailable error if the url is not reachable' do
      chicago.json_url = 'http://bad.url/stations'
      expect{ chicago.stations }.to raise_error(StationListUnavailable)
    end
  end

  describe '#refresh_stations' do
    it 'refreshes the station list and updates the updated_at' do
      VCR.use_cassette('refresh_stations_success') do
        chicago.stations
        first_retrieval = chicago.updated_at
        chicago.refresh_stations
        second_retrieval = chicago.updated_at
        expect(second_retrieval - first_retrieval).to be > 0
      end
    end
  end
end
